package com.bonus.canteen.core.cook.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.bonus.canteen.core.cook.vo.NutritionTypeVO;
import com.bonus.common.log.enums.OperaType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.canteen.core.cook.domain.CookNutrition;
import com.bonus.canteen.core.cook.service.ICookNutritionService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 食材营养基础信息Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "食材营养基础信息接口")
@RestController
@RequestMapping("/cook_nutrition")
public class CookNutritionController extends BaseController {
    @Autowired
    private ICookNutritionService cookNutritionService;

    /**
     * 查询食材营养基础信息列表
     */
    @ApiOperation(value = "查询食材营养基础信息列表")
    @GetMapping("/list")
    public TableDataInfo list(CookNutrition cookNutrition) {
        startPage();
        List<CookNutrition> list = cookNutritionService.selectCookNutritionList(cookNutrition);
        return getDataTable(list);
    }

    /**
     * 导出食材营养基础信息列表
     */
    @ApiOperation(value = "导出食材营养基础信息列表")
    @SysLog(title = "食材营养基础信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出食材营养基础信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, CookNutrition cookNutrition) {
        List<CookNutrition> list = cookNutritionService.selectCookNutritionList(cookNutrition);
        ExcelUtil<CookNutrition> util = new ExcelUtil<CookNutrition>(CookNutrition.class);
        util.exportExcel(response, list, "食材营养基础信息数据");
    }

    /**
     * 获取食材营养基础信息详细信息
     */
    @ApiOperation(value = "获取食材营养基础信息详细信息")
    @GetMapping(value = "/getInfo/{nutritionId}")
    public AjaxResult getInfo(@PathVariable("nutritionId") Long nutritionId) {
        return success(cookNutritionService.selectCookNutritionByNutritionId(nutritionId));
    }

    /**
     * 新增食材营养基础信息
     */
    @ApiOperation(value = "新增食材营养基础信息")
    @SysLog(title = "食材营养基础信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增食材营养基础信息")
    @PostMapping("/add")
    public AjaxResult add(@RequestBody CookNutrition cookNutrition) {
        try {
            return toAjax(cookNutritionService.insertCookNutrition(cookNutrition));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改食材营养基础信息
     */
    @ApiOperation(value = "修改食材营养基础信息")
    @SysLog(title = "食材营养基础信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改食材营养基础信息")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody CookNutrition cookNutrition) {
        try {
            return toAjax(cookNutritionService.updateCookNutrition(cookNutrition));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除食材营养基础信息
     */
    @ApiOperation(value = "删除食材营养基础信息")
    @SysLog(title = "食材营养基础信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除食材营养基础信息")
	@PostMapping("/del/{nutritionIds}")
    public AjaxResult remove(@PathVariable Long[] nutritionIds) {
        return toAjax(cookNutritionService.deleteCookNutritionByNutritionIds(nutritionIds));
    }

    @ApiOperation(value = "根据categoryId获取营养类别集合")
    @PostMapping ("/getListByCategoryId")
    public AjaxResult getListByCategoryId(@RequestBody CookNutrition menuNutrition) {
        List<CookNutrition> list = cookNutritionService.getListByCategoryId(menuNutrition);
        return success(list);
    }
}
